Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1585)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java

Issue 1263573011: Let client specify content description for custom action button (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix corresponding test Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java b/chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java
index fdfad02ea1fd0fbc7f97f992982cbc3dc5ae95f0..80ce2c43057930a27a16bd0db0f7aae2e9707a9f 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/toolbar/ToolbarManager.java
@@ -619,11 +619,13 @@ public class ToolbarManager implements ToolbarTabController, UrlFocusChangeListe
/**
* Adds a custom action button to the {@link Toolbar} if it is supported.
* @param drawable The {@link Drawable} to use as the background for the button.
* @param listener The {@link OnClickListener} to use for clicks to the button.
*/
- public void addCustomActionButton(Drawable drawable, OnClickListener listener) {
- mToolbar.addCustomActionButton(drawable, listener);
+ public void addCustomActionButton(Drawable drawable, String description,
+ OnClickListener listener) {
+ mToolbar.addCustomActionButton(drawable, description, listener);
}
/**
@@ -619,11 +619,13 @@ public class ToolbarManager implements ToolbarTabController, UrlFocusChangeListe
/**
* Adds a custom action button to the {@link Toolbar} if it is supported.
- * @param drawable The {@link Drawable} to use as the background for the button.
- * @param listener The {@link OnClickListener} to use for clicks to the button.
+ * @param drawable The {@link Drawable} to use as the background for the button.
+ * @param description The content description for the custom action button.
+ * @param listener The {@link OnClickListener} to use for clicks to the button.
*/

Powered by Google App Engine
This is Rietveld 408576698